<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
    <head>
	<title>Windmill testing</title>
	<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
    </head>
    <body>
	<div>
	    <h1>Windmill testing</h1>
	    <button id="wm_click" onclick="document.getElementById('wm_target').innerHTML = 'Button clicked'">Click me</button>
	    <div id="wm_target"></div>
	</div>
    </body>
</html>

